import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';
import { dropDownMenu } from './dropDownMenu';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let xColumn;

const onXColumnClicked = column => {
  xColumn = column;  
  render();
};

const render = () => {
  
  select('#menus')
  .call(dropDownMenu, {
    options: data.columns,
    onOptionClicked: onXColumnClicked
  });
  
  svg.call(scatterPlot, {
    title: 'Export (US $)',
    xValue: d => d[xColumn],
    xAxisLabel: 'China',
    yValue: d => d['Japan'],
    circleRadius: 10,
    yAxisLabel: 'Japan',
    margin: { top: 60, right: 40, bottom: 88, left: 150 },
    width,
    height,
    data
  }); 
};

csv('https://vizhub.com/veagy/datasets/2000-2016 Worldwide Exports.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d['China'] = +d['China'];
      d['United States of America'] = +d['United States of America'];
      d['Brazil'] = +d['Brazil'];
      d['India'] = +d['India'];
      d['Japan'] = +d['Japan'];
      d['Mexico'] = +d['Mexico'];
      d['Russian Federation'] = +d['Russian Federation'];
    });
    render();
  });